@@ -6,7 +6,7 @@ var searchData=
   ['cmake_20itself_3',['Useful variables provided by CMake itself',['../md_doc_2buildvariables.html#autotoc_md34',1,'']]],
   ['cmake_20presets_4',['CMake presets',['../index.html#autotoc_md16',1,'']]],
   ['code_5',['Using Visual Studio Code',['../index.html#autotoc_md12',1,'']]],
-  ['configuration_6',['Meta-data and overall project configuration',['../md_doc_2buildvariables.html#autotoc_md41',1,'']]],
+  ['configuration_6',['Metadata and overall project configuration',['../md_doc_2buildvariables.html#autotoc_md41',1,'']]],
   ['copyright_20notice_20and_20license_7',['Copyright notice and license',['../index.html#autotoc_md31',1,'']]],
   ['custom_20variables_8',['Custom variables',['../md_doc_2buildvariables.html#autotoc_md35',1,'']]]
 ];
