@@ -3,5 +3,5 @@ var searchData=
   ['license_0',['Copyright notice and license',['../index.html#autotoc_md31',1,'']]],
   ['linux_20package_1',['Arch Linux package',['../index.html#autotoc_md28',1,'']]],
   ['list_2',['List',['../deprecated.html',1,'Deprecated List'],['../todo.html',1,'Todo List']]],
-  ['location_20of_203rd_20party_20dependencies_3',['Variables for specifying location of 3rd party dependencies',['../md_doc_2buildvariables.html#autotoc_md36',1,'']]]
+  ['location_20of_203rd_20party_20dependencies_3',['Variables for specifying the location of 3rd party dependencies',['../md_doc_2buildvariables.html#autotoc_md36',1,'']]]
 ];
