@@ -1,8 +1,8 @@
 var searchData=
 [
-  ['of_203rd_20party_20dependencies_0',['Variables for specifying location of 3rd party dependencies',['../md_doc_2buildvariables.html#autotoc_md36',1,'']]],
+  ['of_203rd_20party_20dependencies_0',['Variables for specifying the location of 3rd party dependencies',['../md_doc_2buildvariables.html#autotoc_md36',1,'']]],
   ['on_20windows_1',['Remarks for building on Windows',['../index.html#autotoc_md23',1,'']]],
   ['only_20dependencies_2',['Build-only dependencies',['../index.html#autotoc_md5',1,'']]],
   ['opensuse_20and_20fedora_3',['RPM packages for openSUSE and Fedora',['../index.html#autotoc_md29',1,'']]],
-  ['overall_20project_20configuration_4',['Meta-data and overall project configuration',['../md_doc_2buildvariables.html#autotoc_md41',1,'']]]
+  ['overall_20project_20configuration_4',['Metadata and overall project configuration',['../md_doc_2buildvariables.html#autotoc_md41',1,'']]]
 ];
